==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/NotifyEJB/src/com/clustercontrol/notify/factory/AddNotify.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.factory;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import javax.ejb.CreateException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.monitor.bean.QueueConstant;
import com.clustercontrol.notify.bean.NotifyEventInfo;
import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.bean.NotifyInfoContext;
import com.clustercontrol.notify.ejb.entity.NotifyEventInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyEventInfoUtil;
import com.clustercontrol.notify.ejb.entity.NotifyInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyInfoUtil;
import com.clustercontrol.notify.util.SendQueue;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * ξϿ饹
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class AddNotify {
	
	protected static Log m_log = LogFactory.getLog( AddNotify.class );
	
	/**
	 * ξϿ
	 * 
	 * @return Ͽ硢true
	 * @throws CreateException
	 * @throws NamingException
	 */
	@SuppressWarnings("unchecked")
	public boolean add(NotifyInfo info) throws CreateException, NamingException, JMSException {
    	//å
    	AccessLock.lock(AccessLock.NOTIFY);
    	
		SendQueue queue = null;
		try 
		{
			Timestamp now = new Timestamp(new Date().getTime());
			
			// ξ
			NotifyInfoLocal notify = NotifyInfoUtil.getLocalHome().create(
					info.getNotifyId(),
					info.getDescription(),
					info.getStatusFlg(),
					info.getStatusValidPeriod(),
					info.getStatusInvalidFlg(),
					info.getStatusUpdatePriority(),
					info.getEventFlg(),
					info.getInhibitionFlg(),
					info.getInhibitionFrequency(),
					info.getInhibitionPeriod(),
					now,
					now
			);
			Collection ct = notify.getNotifyEventInfo();
			
			ArrayList<NotifyEventInfo> eventList = info.getNotifyEventInfo();
			ArrayList<NotifyEventInfoLocal> eventLocalList = new ArrayList<NotifyEventInfoLocal>();
			
			// Υ٥Ⱦ
			NotifyEventInfo event = null;
			for(int index=0; index<eventList.size(); index++){
				event = (NotifyEventInfo)eventList.get(index);
				if(event != null){
					NotifyEventInfoLocal local = NotifyEventInfoUtil.getLocalHome().create(
							info.getNotifyId(),
							event.getPriority(),
							event.getEventNormalFlg(),
							event.getEventNormalState(),
							event.getEventInhibitionFlg(),
							event.getEventInhibitionState(),
							event.getMailFlg(),
							event.getMailAddress());
					eventLocalList.add(local);
				}
			}
			if(eventLocalList != null){
				ct.addAll(eventLocalList);
				notify.setNotifyEventInfo(ct);
			}
			
			NotifyInfoContext context = new NotifyInfoContext(NotifyInfoContext.TYPE_ADD, info.getNotifyId(), info);
			
			// ξ󥭥å򹹿
			queue = new SendQueue(QueueConstant.QUEUE_NAME_LOG);
			queue.put(context);
			queue.terminate();
			
		} catch (CreateException e) {
            AplLogger apllog = new AplLogger("NOTIFY", "notify");
            String[] args = { info.getNotifyId() };
            apllog.put("SYS", "001", args);
            m_log.debug("add():" + e.getMessage());
			throw e;
		} catch (NamingException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
            String[] args = { info.getNotifyId() };
            apllog.put("SYS", "001", args);
            m_log.debug("add():" + e.getMessage());
			throw e;
		} catch (JMSException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
            String[] args = { info.getNotifyId() };
            apllog.put("SYS", "001", args);
            m_log.debug("add():" + e.getMessage());
			throw e;
		}
		finally{
			if(queue != null){
				queue.terminate();	
			}
		}
		
		return true;
	}
	
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/NotifyEJB/src/com/clustercontrol/notify/factory/AddNotify.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.factory;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import javax.ejb.CreateException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.monitor.bean.QueueConstant;
import com.clustercontrol.notify.bean.NotifyEventInfo;
import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.bean.NotifyInfoContext;
import com.clustercontrol.notify.ejb.entity.NotifyEventInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyEventInfoUtil;
import com.clustercontrol.notify.ejb.entity.NotifyInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyInfoUtil;
import com.clustercontrol.notify.util.SendQueue;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * 通知情報登録クラス
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class AddNotify {
	
	protected static Log m_log = LogFactory.getLog( AddNotify.class );
	
	/**
	 * 通知情報を登録
	 * 
	 * @return 登録に成功した場合、true
	 * @throws CreateException
	 * @throws NamingException
	 */
	@SuppressWarnings("unchecked")
	public boolean add(NotifyInfo info) throws CreateException, NamingException, JMSException {
    	//アクセスロック
    	AccessLock.lock(AccessLock.NOTIFY);
    	
		SendQueue queue = null;
		try 
		{
			Timestamp now = new Timestamp(new Date().getTime());
			
			// 通知情報を挿入
			NotifyInfoLocal notify = NotifyInfoUtil.getLocalHome().create(
					info.getNotifyId(),
					info.getDescription(),
					info.getStatusFlg(),
					info.getStatusValidPeriod(),
					info.getStatusInvalidFlg(),
					info.getStatusUpdatePriority(),
					info.getEventFlg(),
					info.getInhibitionFlg(),
					info.getInhibitionFrequency(),
					info.getInhibitionPeriod(),
					now,
					now
			);
			Collection ct = notify.getNotifyEventInfo();
			
			ArrayList<NotifyEventInfo> eventList = info.getNotifyEventInfo();
			ArrayList<NotifyEventInfoLocal> eventLocalList = new ArrayList<NotifyEventInfoLocal>();
			
			// 通知イベント情報を挿入
			NotifyEventInfo event = null;
			for(int index=0; index<eventList.size(); index++){
				event = (NotifyEventInfo)eventList.get(index);
				if(event != null){
					NotifyEventInfoLocal local = NotifyEventInfoUtil.getLocalHome().create(
							info.getNotifyId(),
							event.getPriority(),
							event.getEventNormalFlg(),
							event.getEventNormalState(),
							event.getEventInhibitionFlg(),
							event.getEventInhibitionState(),
							event.getMailFlg(),
							event.getMailAddress());
					eventLocalList.add(local);
				}
			}
			if(eventLocalList != null){
				ct.addAll(eventLocalList);
				notify.setNotifyEventInfo(ct);
			}
			
			NotifyInfoContext context = new NotifyInfoContext(NotifyInfoContext.TYPE_ADD, info.getNotifyId(), info);
			
			// 通知情報キャッシュを更新
			queue = new SendQueue(QueueConstant.QUEUE_NAME_LOG);
			queue.put(context);
			queue.terminate();
			
		} catch (CreateException e) {
            AplLogger apllog = new AplLogger("NOTIFY", "notify");
            String[] args = { info.getNotifyId() };
            apllog.put("SYS", "001", args);
            m_log.debug("add():" + e.getMessage());
			throw e;
		} catch (NamingException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
            String[] args = { info.getNotifyId() };
            apllog.put("SYS", "001", args);
            m_log.debug("add():" + e.getMessage());
			throw e;
		} catch (JMSException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
            String[] args = { info.getNotifyId() };
            apllog.put("SYS", "001", args);
            m_log.debug("add():" + e.getMessage());
			throw e;
		}
		finally{
			if(queue != null){
				queue.terminate();	
			}
		}
		
		return true;
	}
	
}
